# Variables used for constructing different types of Cepheus Cluster Systems

# M3 defines the size of the construct
#   gives the # out of d6 to find a system in a given parsec
#   1 gives low density, 3 is average, 6 is all parsecs on a subsector map

# short descriptions of jump distances
#  1= jump 3 or often 4 to get to one or more systems, as high as 6!
#  2= mostly jump 2 and jump 3 to get to some systems
#  3= usually jump 2, some jump 1 to get to systems
#  4= mostly jump 1, some jump 2 to reach another system
#  5= almost all jump 1 very rare to have any required jump-2
#  6= all jump 1 as every parsec is occupied.  maximum density

# program designed to require a rectangular array of M3 values
# NOTE !! calculation time increases exponentially with large dense settings!!
#   primarily when determining pocket empires and confederation status


# NOTE: all Clusters with x>6 or y>5 MUST be drawn as sections and assembled, otherwise Octave fails
# known bug with opengl image size for total number of pixels must be less than 8400

# tiny test cluster for system generation errors
# M3(1,1)=[2];


# Open Cluster Play- average ~850 systems
# M3(:,1)=[2 2 2 2 2];
# M3(:,2)=[2 3 3 3 2];
# M3(:,3)=[2 3 4 3 2];
# M3(:,4)=[2 3 3 3 2];
# M3(:,5)=[2 2 2 2 2];

# open clusters give roughly same # worlds as standard Cepheus sectors but
#   make high jump travel important in the periphery
#   also makes a central worlds vs hinterlands setting viable
#   can change 1 to 2 on outside to add systems and reduce jump requirements
#      adds ~ 230 systems and pocket empire processing time


# small test square for speed average ~110 systems
#  M3(:,1)=[2 2];
#  M3(:,2)=[2 2];
#good for testing routines

#{
# large rectangular cluster 80 parsecs on a side (due to the 8x10 subsector maps
 M3(:,1)=[1 1 2 2 2 2 2 2 1 1];
 M3(:,2)=[1 2 2 2 2 2 2 2 2 1];
 M3(:,3)=[2 2 3 3 3 3 3 3 2 2];
 M3(:,4)=[2 2 3 3 4 4 3 3 2 2];
 M3(:,5)=[2 2 3 3 4 4 3 3 2 2];
 M3(:,6)=[2 2 3 3 3 3 3 3 2 2];
 M3(:,7)=[1 2 2 2 2 2 2 2 2 1];
 M3(:,8)=[1 1 2 2 2 2 2 2 1 1];
#}

# medium sized square cluster 40 parsecs on a side
# M3(:,1)=[1 2 2 2 1];
# M3(:,2)=[2 3 4 3 2];
# M3(:,3)=[2 3 4 3 2];
# M3(:,4)=[1 2 2 2 1];


# small free test cluster for showing the program ~280 systems
# M3(:,1)=[2 2 2];
# M3(:,2)=[2 4 2];
# M3(:,3)=[2 2 2];

M3=3*(ones(10,5)); # test for vertically long images

# standard sector for Cepheus engine average ~640 systems
# M3(:,1)=[3 3 3 3];
# M3(:,2)=[3 3 3 3];
# M3(:,3)=[3 3 3 3];
# M3(:,4)=[3 3 3 3];


# good size cluster for traveling ~1200 worlds or so
# add 1 to increase density and reduce importance of high jump multiples
# if added everywhere it adds ~720 worlds to the total and
# processing times go way up for pocket empires
# M3(:,1)=[1 1 1 1 1 1 1];
# M3(:,2)=[1 2 2 2 2 2 1];
# M3(:,3)=[1 2 3 3 3 2 1];
# M3(:,4)=[1 2 3 4 3 2 1];
# M3(:,5)=[1 2 3 3 3 2 1];
# M3(:,6)=[1 2 2 2 2 2 1];
# M3(:,7)=[1 1 1 1 1 1 1];


# really large cluster for Cepheus players who want more space to explore
# add 1 to all values for a high density cluster but
#     will drastically increase pocket empire calculation times!
#     ~2400 worlds expected, roughly the same as a 2x2 sector square


# M3(:,1)=[1 1 1 1 1 1 1 1 1];
# M3(:,2)=[1 2 2 2 2 2 2 2 1];
# M3(:,3)=[1 2 3 3 3 3 3 2 1];
# M3(:,4)=[1 2 3 4 4 4 3 2 1];
# M3(:,5)=[1 2 3 4 5 4 3 2 1];
# M3(:,6)=[1 2 3 4 4 4 3 2 1];
# M3(:,7)=[1 2 3 3 3 3 3 2 1];
# M3(:,8)=[1 2 2 2 2 2 2 2 1];
# M3(:,9)=[1 1 1 1 1 1 1 1 1];


# a Traveller standard domain for the purists ~2600 systems
# M3=3*(ones(8,8));

# a Traveller standard sector for traditionalists
# M3=3*(ones(4,4));

# galactic rift between two normal density settings
# M3(:,1)=[3 3 3 2 1 1];
# M3(:,2)=[3 3 2 1 1 2];
# M3(:,3)=[3 2 1 1 2 3];
# M3(:,4)=[2 1 1 2 3 3];
# M3(:,5)=[1 1 2 3 3 3];

# works well for a bimodal war between equals fighting over the rift
# there are only limited places for 2 empires to contact one another
# recommend syst_explorer=0, syst_hierarchy=0, syst_confederation=0 for this configuration


# habitable zone sizes
# used to define inner, middle, and outer planets
# also used to determine orbital radii for the different ranges
# primary function gamewise- control the number of habitable worlds
# small #'s of middle planets make few habitable worlds

syst_outer= 45;    # 25% of planets are outer planets, rounding up with ceil
syst_middle=35;    # 50% of planets are middle planets, rounding down with floor
                   # remaining planets are inner to prevent rounding errors
                   
syst_orbit_temp=1; # use orbital position to mostly determine planet temperature
                   # 0= determine mostly randomly but modified by position
                   # 1= determine mostly by position but modify by atmo and +/- 1 randomly                   
# increase the number of types of stars and stellar phenomena present in various systems
syst_morestars=1;  # 0= use only main sequqence M,K,G,F types stars
                   # 1= include a range of stellar types in star systems
syst_oddsystems=4; # percent chance out of 100 that an odd system will be present in any hex                   
syst_blackhole=0;  # 0= no central black holes for system  NOT IMPLEMENTED
                   # 1= put a black hole in the center of the setting
                   
# alien population spread- how far out from the homeworld will aliens migrate
# not important for racial pocket empires
                    #1 = low spread- only big populations will be found on nearby worlds
syst_spread=2;      #2 = medium spread- local worlds may have alien contingent
                    #3 = high spread- can extend far around their homeworld

# should uplifts be used when determining populations?
syst_nouplift=1;     #whether there are uplifts or not 0=no, 1=yes

syst_uplifts=25;     #low probability of uplifts (1/50 of worlds)
                     #med probability of uplifts (1/30 of worlds)
                     #high probability of uplifts (1/20 of worlds)

# if a race is found on a populated world, how high a percentage should it be?
                      #1- low percentage (1d3+ 1%) per settled world 
syst_race_numbers=2;  #2- med percentage (1d6+ 2%) per settled world
                      #3- high percentage (1d9+ 3%) per settled world                   

# minimum population for low tech worlds
#   high tech systems can get support from other worlds
#   low tech systems need more independence
#   gives a population bonus for low tech systems making them more viable
syst_lowpop=1;         #0= no minimum   1= put in minimum
syst_min_low_pop=4;    # minimum low population for tech<9 systems


# penalty for systems with no habitable planets
#   how much population is removed for systems without a habitable world?
syst_nohab=2;          # 0= no penalty, bigger numbers= more penalty

# should pocket empires be determined?
# takes the most time of all calculations by far
# gives a very good identifier for the important worlds in a setting though
syst_pockets=1;           # 1=yes    0=no

syst_pocket_tech_max=0;   # should the dominant world's tech be the max for an allied world?
if (syst_pocket_tech_max==1)
  syst_pockets=1;         # if setting a max tech by pocket empire, pocket empires must be chosen
  endif

# frequency of aliens
#   how often are there native species on a habitable world
#   3 stage process: first, if habitable AND pop>syst_racemin may have a race
#                    second, roll 2d6> syst_race
#                    third, rand* (# habitable worlds)* syst_racemod
# eliminate chance of native aliens by making syst_race a 13+ 
syst_racemin=5;      # need a population greater than this to maybe have a native race
syst_race=10;        # 2d6 roll greater than this number 10 for M317 cluster
syst_racemod=1;      # increases the likelihood of a native race when number is large
                     # may need to be changed to fit a high population or higher density setting
                     # syst_race=10 works well for a cluster getting less dense away from the center
                     # recommend syst_race=11 for stnd 50% system density, syst_population 2-3 syst_tech 1-2
# these values give roughly 1 race per subsector in a cluster and other defaults as original
syst_geothermal=175;     # 1 chance out of x to have a geothermally active moon (doubled with tainted atmo)
                         # creates a barely habitable outer world
                         
# do you want races distributed on your planets?
syst_favorable=1;        # should program identify worlds favorable for a major race?
                         # 1=yes it should, 0= no it should NOT
                         # no means no population determination without changing full_populate
syst_popfind=1;          # should program populate worlds by M317 rules?
                         # 1=yes it should, 0= no it should NOT
syst_racebypocket=0;     # should it populate the setting by pocket empire?
#requires completely different population function as race is based on dominant worlds
#race by pocket is incompatable with current full_populate and has a separate function written for it
#race can be determined by pocket empire at least reasonably easily (ie. sys.influ.independence=1)

if (syst_racebypocket==1)  #race by pocket empire requires population finding AND favorable worlds AND pocket empires to be enabled
    syst_popfind=1;
    syst_favorable=1;
    syst_pockets=1;
  endif  

# should there be any explorer society hostels?
syst_explorer=1;        # 1=yes   0=no

# should there be any confederation bases?
# this assumes a setting-wide government that may not be desired
# all naval, scout, and consulates are determined using 1 variable for internal simplicity
syst_confederation=1;   # 1=yes   0=no


# should there be a confederation status?
# assumes a hierarchical confederation based on population and tech level
# definitely not needed for pocket empires
# MUST keep sy.confed variable (kept at 0) for pocket empire use
syst_hierarchy=1;        # 1=yes   0=no
                         # this number of parsecs and beyond bases do not exchange information weekly
syst_weeklyreport=6;     # should have a value >1 even when no confederation is present!
                         # is used for determining how centrally located a system is
syst_exchanging_bases=1;  #1: count of how many bases a confederation base shares information with 
                          #0: do not count nearby bases
if (syst_hierarchy==1)     # if there is a hierarchy, then confederation bases must also exist
    syst_confederation=1;
  endif 
  
# check for factions in a system?
#    really isn't used for much other than in the case of balkanized systems
#    might be cool for cultural or societal tendencies
#    if/when I get around to adding those
syst_factions=1;          # 1=yes    0=no


# random system names
#    uses a function called namegen that I wrote
#    to use a different name generator it must be compatable with octave
#    should change line ~1042 of trav_system to call the alternative name generator
#    there are a lot of name generators out there!

# technology levels on average 
#                 always a range of tech, but sometimes rarer high-tech planets might be desired
syst_tech=1;      # 0= low tech, 1=mid tech, 2=higher tech, 3= rather high tech
#                 can change betweeen subsectors when expending a setting
#                 occurs in full_system ~line 810+
syst_techmax=15;    # maximum tech level for a system under any circumstance
                    # allows creation of a setting with a limited tech level
                    
# population levels on average
#                  always a range of population sizes, but having less than a million sophonts on a whole planet is low
syst_population=3; #0= very high, 1=higher 2=high-mid, 3= low-mid, 4= lower, 5=quite low, lots unexplored
#                  also affected by the number of habitable worlds and other factors
#                  found in full_system ~ line 675
syst_pop_boost=0;      # should ONLY be non-zero for population 5 (maybe 4) above
                       # adds syst_pop_boost to every non-zero, non-10 population planet
                       
# should the program print travel times in normal space between planets?
syst_traveltime=0;      # should no longer use as it only prints the SHORTEST time between planets

# should the program print information about population centers in the system?                        
syst_popcenter=1;       #0= do NOT print
                        #1= print list (2 or 3 items with sizes of main settlements in system    
                  
# identify empires by their ability to build starships (ie. starport= A)
syst_starempire=0;      # 0= influence is independent of building starships
                        # 1= must build starships to influence systems around you; starships help influence
if (syst_starempire==1)
    syst_pockets=1;         # pocket empires should be enabled
    syst_racebypocket=1;    # determine race based on pocket empire
    syst_favorable=1;       # required for racebypocket
    syst_confederation=0;   # no overall confederation
    syst_hierarchy=0;       # no consideration of confederation standing
  endif                      
                        
syst_portbooster=1;     # increase the probabability of a starport
                        # higher the number, the bigger the boost
                        # generally useful for lower population systems where worlds may be too isolated  
                   
syst_personalities=1;   # 1= calculate them    0= ignore them
                        # generates system attitudes towards 15 criteria for roleplaying situations
                        # modified by sophonts in system, trade characteristics, and interstellar contacts

syst_topprint=2;      # what percentage of 'top' systems to print in the overall setting summary
                        # round up just because

syst_temperature= "C";  # identifies which temperature scale to use
                        # C for celsius, F for Farenheit

syst_imagetype="png";   # image type for subsector file creation
                        # png is most reliable
                        # pdf works often BUT starts failing in ghostscript unpredictably and not easily fixed                        
                   