# populate a setting based on pocket empires
# requires a sys(a,b,c) variable with the influence scores already calculated

# lack of influence scores will prevent any world from receiving a population effectively


# give any independent world a unique race
# when choosing a major race (insectan, reptilian, merfolk, avian) a world in the system must be appropriate
# uplifted races (felines, mongoose, apes) must also be appropriate
#         dolphins cannot be a dominant race due to physical limitations
# cannot choose a minor race if no world is habitable
full_variables      # make sure all variables needed are loaded

if (exist("newrace.mat")==2)
    load "newrace.mat"  # get all of the possible races
  endif  
more off
favrace=(-1)*ones(length(sys(:,1,1)), length(sys(1,:,1)), length(sys(1,1,:)));  # make favrace vector -1

for a=1:length(sys(:,1,1))          # assign favorite races to all independent worlds
  for b=1:length(sys(1,:,1))
    for c=1:length(sys(1,1,:))
      if (sys(a,b,c).starnum>0)         # must be a system
          if (sys(a,b,c).influ.independent==1)        # must be independent
              if (sys(a,b,c).native>0)
                  for d=1:length(newrace)
                    e=distance(sys(a,b,c), newrace(d));
                    if (e==0)                      # if the independent world is a homeworld, it is the favored race
                        favrace(a,b,c)=d+10;
                        printf("%d %d %d has a minor race empire ruled by %d.\n", a,b,c, d+10);
                      endif
                    endfor  
                else
                  if (roll(2)>11)  # choose an uplifted race
                      favrace(a,b,c)=4+ceil(rand()*3);
                      printf("%d %d %d has an uplifted race empire ruled by %d.\n", a,b,c, favrace(a,b,c));
                    else
                      if (sys(a,b,c).habnum==0)         # choose a random major race if no habitable worlds
                          favrace(a,b,c)=floor(rand()*5);     
                        else                            # choose a habitable world and make it's favored race the empire's
                          favrace(a,b,c)= sys(a,b,c).favor(sys(a,b,c).habit.planet(ceil(rand()*sys(a,b,c).habnum)));
                          printf("%d %d %d has a major race empire ruled by %d.\n   ", a,b,c, favrace(a,b,c));
                          for d=1:sys(a,b,c).habnum
                            printf("  %d", sys(a,b,c).favor(sys(a,b,c).habit.planet(d)));
                            endfor
                          printf("\n");
                        endif  
                    endif  
                endif
            endif    
        endif
      endfor
    endfor
  endfor
  
for a=1:length(sys(:,1,1))          # assign favorite races to dependent worlds with pocket empires
  for b=1:length(sys(1,:,1))
    for c=1:length(sys(1,1,:))
      if (sys(a,b,c).starnum>0)
          if ((sys(a,b,c).influ.independent==0)*(sys(a,b,c).influ.ally(1,1)>0))   # if a dominated world has its own pocket empire
              d=sys(a,b,c).influ.ndx(1,:); # choose first entry as the dominant system 
              printf("%d %d %d is a pocket dominated by %d %d %d with a favrace of %d.\n",a,b,c, d(1), d(2), d(3), favrace(d(1), d(2), d(3))); 
              favrace(a,b,c)= favrace(d(1), d(2), d(3));    # assign the same favored race to the dominant system
            endif  
        endif
      endfor
    endfor
  endfor
  
for a=1:length(sys(:,1,1))          # assign favorite races to unassigned worlds
  for b=1:length(sys(1,:,1))
    for c=1:length(sys(1,1,:))
      if (sys(a,b,c).starnum>0)
          if (favrace(a,b,c)<0)
              d=sys(a,b,c).influ.ndx(1,:); # choose first entry as the dominant system  
              favrace(a,b,c)= favrace(d(1), d(2), d(3));    # assign the same favored race to the dominant system
            endif  
          if (favrace(a,b,c)<0)
              if (sys(a,b,c).habnum==0)         # choose a random major race if no habitable worlds
                  favrace(a,b,c)=floor(rand()*5);     
                else                            # choose a habitable world and make it's favored race the empire's
                  favrace(a,b,c)= sys(a,b,c).favor(sys(a,b,c).habit.planet(ceil(rand()*sys(a,b,c).habnum)));
                  printf("%d %d %d has a major race empire ruled by %d.\n   ", a,b,c, favrace(a,b,c));
                  for d=1:sys(a,b,c).habnum
                    printf("  %d", sys(a,b,c).favor(sys(a,b,c).habit.planet(d)));
                    endfor
                  printf("\n");
                endif
            endif    
        endif
      endfor
    endfor
  endfor

# all worlds should be assigned a favrace here

# need to populate the worlds
# must use the same variables as full_populate and assign values appropriately
# the favored race is the most numerous UNLESS
#      1. there are no livable worlds in the system for that race
#      2. the system has a minor race homeworld
#      
# major races show up a certain percentage of the time based on the # of favorable worlds
# minor races show up a random percentage of the time if they are not the favored race

#0=humans, #1=avians, #2=insectans, #3=merfolk, #4=reptilians #5= uplifted apes, #6=uplifted felines, #7=uplifted mongoose #8= uplifted dolphins

nm=['human';'avian';'insectan';'merfolk';'reptilian';'uplifted ape';'uplifted feline';'uplifted mongoose';'uplifted dolphin'];

for a=1:length(sys(:,1,1))          # assign populations of each race to a world
  for b=1:length(sys(1,:,1))
    for c=1:length(sys(1,1,:))
      # if there is a native species, find the race living on a planet
      if (sys(a,b,c).native>0)  
          for d=1:length(newrace)
            t1= (newrace(d).sector(1)==sys(a,b,c).sector(1));
            t2= (newrace(d).sector(2)==sys(a,b,c).sector(2));
            t3= (newrace(d).subsector(1)==sys(a,b,c).subsector(1));
            t4= (newrace(d).subsector(2)==sys(a,b,c).subsector(2));
            if ((t1+t2+t3+t4)==4)
                homerace=d+10;
              endif
            endfor
        else
          homerace=0;    
        endif
   if (sys(a,b,c).starnum>0)   
       if (sys(a,b,c).native>0)    #planet has a native species
            pmix(1).pp= ceil(rand()*6)*3+5;
            pmix(1).pn= favrace(a,b,c);
            if (pmix(1).pn<11)
               pmix(1).pname= nm(favrace(a,b,c)+1,:);
              else
                pmix(1).pname= newrace(favrace(a,b,c)-10).race.name;  
              endif  
            pmix(2).pp=100-pmix(1).pp;
            pmix(2).pn= homerace;
            pmix(2).pname= newrace(homerace-10).race.name;
            if (pmix(1).pn==pmix(2).pn)   #if the favored race and the homerace are the same, combine entries
                pmix(1).pp=100;
                pmix=pmix(1);
              endif  
          else                    # planet does not have a native species
            pmix(1).pp=100;
            pmix(1).pn=favrace(a,b,c);
            if (pmix(1).pn<11)
                pmix(1).pname= nm(favrace(a,b,c)+1,:);
              else
                pmix(1).pname= newrace(favrace(a,b,c)-10).race.name;  
              endif  
          #figure out who likes living in the system
            if (sys(a,b,c).tech<8)   # if no space travel, only the most habitable world is occupied
                bestp=sys(a,b,c).bestp;
                bestm=sys(a,b,c).bestm;
                unfav=0;    # reset the unfavorable count to 0
                newfly=0;
                if (bestm==0) # most livable world is a planet
                    atmo= sys(a,b,c).atm(bestp);
                    hydro= sys(a,b,c).hydro(bestp);
                    grav= sys(a,b,c).gravity(bestp);
                    temp= sys(a,b,c).temp(bestp);
                    favor(1)= sys(a,b,c).favor(bestp);
                  else                   # most livable world is a moon
                    atmo= sys(a,b,c).moon.atm(bestp,bestm);
                    hydro= sys(a,b,c).moon.hydro(bestp, bestm);
                    grav= sys(a,b,c).moon.gravity(bestp, bestm);
                    temp= sys(a,b,c).moon.temp(bestp, bestm);
                    favor(1)= sys(a,b,c).moon.favor(bestp, bestm);
                  endif
                newfly= newfly + ((((grav<0.6)*(atmo>5))+((grav<0.9)*(atmo>8)))>0); # can fly on world
                if (favrace(a,b,c)==0)    # for humans
                    unfav=unfav + ((atmo==4)+(atmo==7)+(atmo==9));  
                  endif
                if (favrace(a,b,c)==1)    # for avians
                    unfav= unfav+ ((atmo==4)+(atmo==7)+(atmo==9)) + (newfly==0);
                  endif
                if (favrace(a,b,c)==2)    # for insectans
                    unfav= unfav+ ((atmo==5)+(atmo==6)+(atmo==8));
                  endif
                if (favrace(a,b,c)==3)    # for merfolk
                    unfav= unfav+ (hydro<5) + ((atmo==4)+(atmo==7)+(atmo==9));
                  endif
                if ((favrace(a,b,c)>3)*(favrace(a,b,c)<8))      # for the rest
                    unfav= unfav+ ((atmo==4)+(atmo==7)+(atmo==9));
                  endif
                rac=favrace(a,b,c)-10;  
                if (favrace(a,b,c)>10)
                    for d=1:newrace(rac).race.traits   # for minor races, must check all their traits
                      unfav= unfav+ (((newrace(rac).race.trait(d)==63)+(newrace(rac).race.trait(d)==64))*(hydro>3))*2;
                      unfav= unfav+ (((newrace(rac).race.trait(d)==7)+(newrace(rac).race.trait(d)==8))*(temp<4));
                      unfav= unfav+ (((newrace(rac).race.trait(d)==12)+(newrace(rac).race.trait(d)==13))*(temp>4));
                      unfav= unfav+ ((newrace(rac).race.trait(d)==69)*(hydro<3))*3;
                      unfav= unfav+ ((newrace(rac).race.trait(d)==72)*(grav<.7))*3;
                      unfav= unfav+ ((newrace(rac).race.trait(d)==79)*((atmo==5)+(atmo==6)+(atmo==8)));
                      unfav= unfav+ (((newrace(rac).race.trait(d)>79)*(newrace(rac).race.trait(d)<83))*(atmo<8))*2;
                      unfav= unfav+ ((atmo==4)+(atmo==7)+(atmo==9))-(((newrace(rac).race.trait(d)==79)+(newrace(rac).race.trait(d)==78))*((atmo==4)+(atmo==7)+(atmo==9)));
                      endfor
                  endif
                if (unfav>0)     # empire race is a minority if they don't like living on the planet
                    up= ceil(rand()*syst_uplifts);
                    ch= floor(rand()*2);         
                    if (ch>0)   # use the favored race of the planet
                        pmix(2).pn= favor(1);
                        pmix(2).pp= 70+ floor(rand()*27);
                        pmix(1).pp= 100-pmix(2).pp;
                        pmix(2).pname= nm(pmix(2).pn+1,:);
                      else        #choose human or uplift
                        pmix(2).pn= (up==1)* floor(rand()*4)+5;  
                        if (pmix(2).pn==8)
                            pmix(2).pn= 8* (hydro>4);
                          endif
                        pmix(2).pname= nm(pmix(2).pn+1,:);
                        pmix(2).pp= 70+ floor(rand()*27);
                        pmix(1).pp= 100-pmix(2).pp;  
                      endif
                    if (pmix(1).pn==pmix(2).pn)   #if the favored race and the chosen race are the same, combine entries
                        pmix(1).pp=100;
                        pmix=pmix(1);
                      endif
                    if ((length(pmix)==2)*(sys(a,b,c).population<4))   # if a vestigial population, empire race doesn't want
                        pmix=pmix(1);
                        pmix(1).pp=100;
                      endif  
                  endif
              else        # system tech>7 (ie. has spaceflight even if not jump tech) all system worlds count
                unfav=0;    # reset the unfavorable count to 1  any livable world gives the favrace preference
                favor=zeros(1,9);  # race+1 which has a favored planet in the system
                newfly=0;
                for e=1:sys(a,b,c).habnum      # count through all habitable planets; if no habitable, favrace dominates
                  f= sys(a,b,c).habit.planet(e);
                  if (sys(a,b,c).habit.moon(e)==0) # habitable world is a planet
                      atmo= sys(a,b,c).atm(f);
                      hydro= sys(a,b,c).hydro(f);
                      grav= sys(a,b,c).gravity(f);
                      temp= sys(a,b,c).temp(f);
                      favor(sys(a,b,c).favor(f)+1)= favor(sys(a,b,c).favor(f)+1)+1;  # allow this race to show up in population
                    else                   # habitable world is a moon
                      bestm= sys(a,b,c).habit.moon(e);
                      atmo= sys(a,b,c).moon.atm(f,bestm);
                      hydro= sys(a,b,c).moon.hydro(f,bestm);
                      grav= sys(a,b,c).moon.gravity(f,bestm);
                      temp= sys(a,b,c).moon.temp(f,bestm);
                      favor(sys(a,b,c).moon.favor(f,bestm)+1)= favor(sys(a,b,c).moon.favor(f,bestm)+1)+1;
                    endif
                  newfly= newfly+ ((((grav<0.6)*(atmo>5))+((grav<0.9)*(atmo>8)))>0); # can fly on world
                  rac=favrace(a,b,c)-10;  
                  if (favrace(a,b,c)>10)
                      newfav=ones(1,sys(a,b,c).habnum);  # planets are favorable unless determined otherwise
                      for d=1:newrace(rac).race.traits   # for minor races, must check all their traits
                        newfav(e)= newfav(e)- (((newrace(rac).race.trait(d)==63)+(newrace(rac).race.trait(d)==64))*(hydro<4));
                        newfav(e)= newfav(e)- (((newrace(rac).race.trait(d)==7)+(newrace(rac).race.trait(d)==8))*(temp>4));
                        newfav(e)= newfav(e)- (((newrace(rac).race.trait(d)==12)+(newrace(rac).race.trait(d)==13))*(temp<4));
                        newfav(e)= newfav(e)- ((newrace(rac).race.trait(d)==69)*(hydro>4));
                        newfav(e)= newfav(e)- ((newrace(rac).race.trait(d)==72)*(grav>.7));
                        newfav(e)= newfav(e)- ((newrace(rac).race.trait(d)==79)*((atmo==5)+(atmo==6)+(atmo==8)));
                        newfav(e)= newfav(e)- (((newrace(rac).race.trait(d)>79)*(newrace(rac).race.trait(d)<83))*(atmo>7));
                        newfav(e)= newfav(e)- ((atmo==4)+(atmo==7)+(atmo==9))+((newrace(rac).race.trait(d)==79)*((atmo==5)+(atmo==6)+(atmo==8)))+((newrace(rac).race.trait(d)==78)*((atmo>3)*(atmo<10)));
                        endfor
                    endif
                  endfor
                # does favrace have a planet that they like here?
                wanted=0;
                if (sys(a,b,c).habnum==0)
                    wanted=1;
                    pleft=0;
                    favor(favrace(a,b,c)+1)=2;
                  elseif (favrace(a,b,c)<5)
                    wanted=(favor(favrace(a,b,c)+1)>0);
                  elseif (favrace(a,b,c)>10)
                    for e=1:sys(a,b,c).habnum
                      wanted= wanted+ (newfav(e)==1);
                      endfor
                    wanted=(wanted>0);
                  else 
                    wanted=(favor(1)>0)+(favor(2)>0)+ (favor(4)>0);
                    wanted=(wanted>0);
                  endif
                if (wanted==0)     # not wanted by favrace
                    pmix(1).pp= ceil(rand()*6)*2 +5;
                    pleft= 100- pmix(1).pp;
                    d=0;
                    d= 1*(sys(a,b,c).population<4);
                    d=d+ 2*(sys(a,b,c).population<6)*(sys(a,b,c).population>3);
                    favor(1)=favor(1)+1;
                    for e=5:8
                      favor(e)=(ceil(rand()*syst_uplifts)==1);
                      endfor
                    tot=sum(favor);  # count number of favored races present  
                    if (d==1)        # population <4
                        e=floor(rand()*tot);
                        f=1;
                        while (e>0)
                          e=e-favor(f);
                          f=f+1;
                          endwhile
                        pmix(2).pp=pleft;
                        pmix(2).pn=f-1;
                        pmix(2).pname=nm(f,:);
                        if (pmix(2).pn==pmix(1).pn)
                            pmix(1).pp=100;
                            pmix=pmix(1);
                          endif  
                      elseif (d==2)  # population 4-5
                        e=floor(rand()*tot);
                        f=1;
                        while (e>0)
                          e=e-favor(f);
                          f=f+1;
                          endwhile
                        pmix(2).pp=pleft-(ceil(rand()*20)+10);
                        pmix(2).pn=f-1;
                        pmix(2).pname=nm(f,:);
                        pleft=pleft-pmix(2).pp;
                        e=floor(rand()*tot);
                        f=1;
                        while (e>0)
                          e=e-favor(f);
                          f=f+1;
                          endwhile
                        pmix(3).pp=100- pmix(1).pp- pmix(2).pp;
                        pmix(3).pn=f-1;
                        pmix(3).pname=nm(f,:);
                        if (pmix(1).pn==pmix(3).pn)
                            pmix(1).pp= pmix(1).pp + pmix(3).pp;
                            pmix= pmix(1:2);
                          elseif (pmix(2).pn==pmix(3).pn)
                            pmix(2).pp=100-pmix(1).pp;
                            pmix=pmix(1:2);
                          endif
                        if (pmix(1).pn==pmix(2).pn)   #if the favored race and the chosen race are the same, combine entries
                            pmix(1).pp= pmix(1).pp+ pmix(2).pp;
                            if (length(pmix)>2)
                                pmix(2)=pmix(3);
                                pmix=pmix(1:2);
                              endif  
                          endif  
                        if (pmix(1).pp==100)
                            pmix=pmix(1);
                          endif  
                      else            # population 6+
                        e= floor(pleft/tot);
                        g=2;
                        for f=2:9
                          if ((favor(f)>0)*(f!=favrace(a,b,c)+1))   # does a race but not the favored race exist in this system?
                              pmix(g).pn=f-1;
                              pmix(g).pname=nm(f,:);
                              pmix(g).pp= favor(f)*e + ceil(rand()*(4*favor(f)))-floor(4*favor(f)/2);
                              pmix(g).pp= max(4, pmix(g).pp);
                              pleft=pleft- pmix(g).pp;
                              g=g+1;
                            endif
                          endfor
                        if (pleft<0)
                            pmix(g-1).pp= pmix(g-1).pp + pleft;  # if negative humans, remove some of last race instead
                          elseif(favrace(a,b,c)==0)
                            pmix(1).pp= pmix(1).pp + pleft;
                          else
                            pmix(g).pn=0;
                            pmix(g).pname=nm(1,:);
                            pmix(g).pp= pleft;
                          endif
                      endif  
                    else    # favrace likes at least one planet in the system
                      if (sys(a,b,c).population>5)    #only if 6+ population
                          pmix(1).pp= 50+ ceil(rand()*30);
                          pleft=100-pmix(1).pp;
                          e= floor(pleft/sum(favor));
                          g=2;
                          for f=2:9
                            if ((favor(f)>0)*(f!=favrace(a,b,c)+1))   # does a race but not the favored race exist in this system?
                                pmix(g).pn=f-1;
                                pmix(g).pname=nm(f,:);
                                pmix(g).pp= favor(f)*e + ceil(rand()*(3*favor(f)))-floor(3*favor(f)/2);
                                pmix(g).pp= min(pleft, pmix(g).pp);
                                pmix(g).pp= max(2, pmix(g).pp);
                                pleft=pleft- pmix(g).pp;
                                g=g+1;
                              endif
                            endfor
                        if (favrace(a,b,c)==0)
                            pmix(1).pp= pmix(1).pp + pleft;
                          else
                            pmix(g).pn=0;
                            pmix(g).pname=nm(1,:);
                            pmix(g).pp= pleft;
                          endif  
                        endif  
                    endif      
              endif
          endif  
    
    
      #{ 
      if ((sys(a,b,c).starnum>0)*(sys(a,b,c).tech>7))
          # key variables for if a race wants to live in the system            
          newhydro=0;     #must be 1+ for swimmers
          newfly=0;       #must be 1+ for fliers
          newcold=0;      #must be 1+ for cold adapted
          newhot=0;       #must be 1+ for heat adapted
          newdesert=0;    #must be 1+ for desert adapted
          newlowgrav=0;   #must be 1+ for low grav adapted
          newtaint=0;     #must be 1+ for taint adapted
          newfresh=0;     #must be 1+ for normal breather
          newlowatm=0;    #must be 1+ for trace breathers
          favor=zeros(1,9); #none of the main races have favored status here
          for d=1:sys(a,b,c).habnum           # cycle through all the habitable worlds
            newhydro= newhydro+ (sys(a,b,c).habit.hydro(d)>3);     # at least one 40% water world
            newcold= newcold + (sys(a,b,c).habit.temp(d)<4);       # at least one cool- world
            newhot= newhot + (sys(a,b,c).habit.temp(d)>4);         # at least one warm+ world
            newdesert= newdesert + (sys(a,b,c).habit.hydro(d)<4);  # at least one less than 40% water world
            newtaint= newtaint +((sys(a,b,c).habit.atm(d)==4)+(sys(a,b,c).habit.atm(d)==7)+(sys(a,b,c).habit.atm(d)==9));  # at least one tainted atmosphere
            newfresh= newfresh +((sys(a,b,c).habit.atm(d)==5)+(sys(a,b,c).habit.atm(d)==6)+(sys(a,b,c).habit.atm(d)==8));  # at least one fresh atmosphere
            newlowatm= newlowatm + (sys(a,b,c).habit.atm(d)<8);   # at least one stnd atm or lower
            if (sys(a,b,c).habit.moon(d)==0)     # use planet stats for planets
                grav=sys(a,b,c).gravity(d);
                fav=sys(a,b,c).favor(d);
                atmo=sys(a,b,c).atm(d);
              else                               # use moon stats for moons
                grav=sys(a,b,c).moon.gravity(d, sys(a,b,c).habit.moon(d));
                fav=sys(a,b,c).moon.favor(d, sys(a,b,c).habit.moon(d));
                atmo=sys(a,b,c).moon.atm(d, sys(a,b,c).habit.moon(d));
              endif
            favor(fav+1)=favor(fav+1)+1;   # make a favored race possible
            newlowgrav= newlowgrav + (grav<0.7);   # at least one low grav world
            newfly= newfly + ((((grav<0.6)*(atmo>5))+((grav<0.9)*(atmo>8)))>0); # can fly on at least 1 world
            endfor
          # give uplifts an opportunity
          if (syst_uplifts>0)
              for d=5:7
                favor(d+1)=(ceil(rand()*syst_uplifts)==1)*(newfresh>0);
                endfor
              favor(9)= (ceil(rand()*syst_uplifts)==1)*(newhydro>0)*(newfresh>0);
            endif  
          unfav=0;     # start with nothing unfavorable  
          if (favrace(a,b,c)==0)    # for humans
              unfav=(newfresh==0);  
            endif
          if (favrace(a,b,c)==1)    # for avians
              unfav=(newfresh==0) + (newfly==0);
             endif
          if (favrace(a,b,c)==2)    # for insectans
              unfav=(newtaint==0);
            endif
          if (favrace(a,b,c)==3)    # for merfolk
              unfav=(newhydro==0) + (newfresh==0);
            endif
          if ((favrace(a,b,c)>4)*(favrace(a,b,c)<8)) # for reptilians and uplifts
              unfav=(newfresh==0);
            endif
          rac=favrace(a,b,c)-10;  
          if (favrace(a,b,c)>10)
              for d=1:newrace(rac).race.traits   # for minor races, must check all their traits
                unfav= unfav+ (((newrace(rac).race.trait(d)==63)+(newrace(rac).race.trait(d)==64))*(newhydro==0))*2;
                unfav= unfav+ (((newrace(rac).race.trait(d)==7)+(newrace(rac).race.trait(d)==8))*(newcold==0));
                unfav= unfav+ (((newrace(rac).race.trait(d)==12)+(newrace(rac).race.trait(d)==13))*(newhot==0));
                unfav= unfav+ ((newrace(rac).race.trait(d)==69)*(newdesert==0))*3;
                unfav= unfav+ ((newrace(rac).race.trait(d)==72)*(newlowgrav==0))*3;
                unfav= unfav+ ((newrace(rac).race.trait(d)==79)*(newtaint==0));
                unfav= unfav+ (((newrace(rac).race.trait(d)>79)*(newrace(rac).race.trait(d)<83))*(newlowatm==0))*2;
                unfav= unfav+ (newfresh==0)-(((newrace(rac).race.trait(d)==79)+(newrace(rac).race.trait(d)==78))*(newfresh==0));
                endfor
            endif
          # find the percentages of the races in this system
          pcnt=0;
          favor(1)= favor(1)+1; # humans are everywhere
          totfav=sum(favor);  
          if (sys(a,b,c).native==0)   # no native races
              pmix(1).pp=((80/(unfav*3+1))+ceil(rand()*6)+1);
              pmix(1).pn=favrace(a,b,c);
              if (favrace(a,b,c)<11)
                  pmix(1).name=nm(favrace(a,b,c)+1,:);
                else
                  pmix(1).name=newrace(favrace(a,b,c)-10).name;
                endif
              pleft=100-pmix(1).pp;
              pcnt=1;
            else                       # with a native race
              pmix(1).pp=((20/(unfav*3+1))+ceil(rand()*6)+1);
              pmix(1).pn=favrace(a,b,c);
              if (favrace(a,b,c)<11)
                  pmix(1).name=nm(favrace(a,b,c)+1,:);
                else
                  pmix(1).name=newrace(favrace(a,b,c)-10).name;
                endif
              pmix(2).pp= (85+ceil(rand()*6)+1)-pmix(1).pp;
              pmix(2).pn= homerace;
              pmix(2).name=sys(a,b,c).race.name;
              pcnt=2;
              pleft= 100-pmix(1).pp-pmix(2).pp;
              if (pmix(1).pn==pmix(2).pn)            # if it is the homeworld of a dominant race
                  pmix(1).pp= pmix(1).pp+ pmix(2).pp;
                  pmix(1).pp= min(95, pmix(1).pp);  # can't have more than 95% native on a homeworld
                  pcnt=1;
                  pleft= 100-pmix(1).pp;
                  pmix(2).pn=0;                     # get rid of the second race
                  pmix(2).pp=0;
                  pmix(2).name="";
                endif  
            endif
          # assign the rest of the sophonts in the system based on favored worlds
          pavg= floor(pleft/totfav);
          for d=2:9
            if (favor(d)>0)
                pmix(pcnt).pp=pavg*favor(d)-1+floor(rand*3);
                pmix(pcnt).pn=d-1;
                pmix(pcnt).name=nm(d,:);
                pleft=pleft-pmix(pcnt).pp;
                pcnt=pcnt+1;
              endif
          endfor  
          pmix(pcnt).pn=0;
          pmix(pcnt).pp=max(pleft,1);
          pmix(pcnt).name=nm(1,:);      

        elseif (sys(a,b,c).starnum>0)          #tech level is pre-space flight
          bestp=sys(a,b,c).bestp;
          bestm=sys(a,b,c).bestm;
          if (bestm==0) # most livable world is a planet
              atmo= sys(a,b,c).atm(bestp);
              hydro= sys(a,b,c).hydro(bestp);
              grav= sys(a,b,c).gravity(bestp);
              temp= sys(a,b,c).temp(bestp);
              favor(1)= sys(a,b,c).favor(bestp);
            else                   # most livable world is a moon
              atmo= sys(a,b,c).moon.atm(bestp,bestm);
              hydro= sys(a,b,c).moon.hydro(bestp, bestm);
              grav= sys(a,b,c).moon.gravity(bestp, bestm);
              temp= sys(a,b,c).moon.temp(bestp, bestm);
              favor(1)= sys(a,b,c).moon.favor(bestp, bestm);
            endif
          newfly= newfly + ((((grav<0.6)*(atmo>5))+((grav<0.9)*(atmo>8)))>0); # can fly on world
          if (favrace(a,b,c)==0)    # for humans
              unfav=unfav + ((atmo==4)+(atmo==7)+(atmo==9));  
            endif
          if (favrace(a,b,c)==1)    # for avians
              unfav= unfav+ ((atmo==4)+(atmo==7)+(atmo==9)) + (newfly==0);
             endif
          if (favrace(a,b,c)==2)    # for insectans
              unfav= unfav+ (newtaint==0);
            endif
          if (favrace(a,b,c)==3)    # for merfolk
              unfav= unfav+ (newhydro==0) + (newfresh==0);
            endif
          if ((favrace(a,b,c)>3)*(favrace(a,b,c)<8))      # for the rest
              unfav= unfav+ ((atmo==4)+(atmo==7)+(atmo==9));
            endif
          rac=favrace(a,b,c)-10;  
          if (favrace(a,b,c)>10)
              for d=1:newrace(rac).race.traits   # for minor races, must check all their traits
                unfav= unfav+ (((newrace(rac).race.trait(d)==63)+(newrace(rac).race.trait(d)==64))*(hydro>3))*2;
                unfav= unfav+ (((newrace(rac).race.trait(d)==7)+(newrace(rac).race.trait(d)==8))*(temp<4));
                unfav= unfav+ (((newrace(rac).race.trait(d)==12)+(newrace(rac).race.trait(d)==13))*(temp>4));
                unfav= unfav+ ((newrace(rac).race.trait(d)==69)*(hydro<3))*3;
                unfav= unfav+ ((newrace(rac).race.trait(d)==72)*(grav<7))*3;
                unfav= unfav+ ((newrace(rac).race.trait(d)==79)*((atmo==5)+(atmo==6)+(atmo==8)));
                unfav= unfav+ (((newrace(rac).race.trait(d)>79)*(newrace(rac).race.trait(d)<83))*(atmo<8))*2;
                unfav= unfav+ ((atmo==4)+(atmo==7)+(atmo==9))-(((newrace(rac).race.trait(d)==79)+(newrace(rac).race.trait(d)==78))*((atmo==4)+(atmo==7)+(atmo==9)));
                endfor
            endif
          if (sys(a,b,c).native==0)  # no native species
              pmix(1).pp= (unfav==0)* 100 + (unfav>0)*(ceil(rand()*6))+5;
              pmix(1).pn= favrace(a,b,c);
              if (favrace(a,b,c)<10)
                  pmix(1).name= nm(favrace(a,b,c)+1,:);
                else
                  pmix(1).name= newrace(favrace(a,b,c)-10).name;
                endif
              pmix(2).pp= 100- pmix(1).pp;
              pmix(2).pn= favor(1)+1;
              pmix(2).name= nm(favor(1)+1,:);
            else
              pmix(1).pp= ceil(rand()*6)+5;
              pmix(1).pn= homerace;
              if (favrace(a,b,c)<10)
                  pmix(1).name=nm(favrace(a,b,c)+1,:);
                else
                  pmix(1).name=newrace(favrace(a,b,c)-10).name;  
                endif
              pmix(2).pp= 100-pmix(1).pp;
              pmix(2).pn= homerace;
              pmix(2).name= sys(a,b,c).race.name;  
            endif    
        endif
        
        #}
        
        
        
          sys(a,b,c).populate=pmix;
          clear pmix  
        endif
      endfor
    endfor
  endfor
more on
  
    

    